@@ -46,7 +46,6 @@ void saveDataToNode(MainView * mainview, nodeData *selnode);
 gboolean callback_node_view_window_state(GtkWidget* window, GdkEventWindowState* event, gpointer user_data);
 
 gboolean callback_treeview_button_press(GtkTreeView* treeview, GdkEventButton* event, gpointer user_data);
-gboolean callback_treeview_testcollapse(GtkTreeView * treeview, GtkTreeIter * arg1, GtkTreePath * arg2, gpointer user_data);
 void callback_treeview_celldatafunc(GtkTreeViewColumn * tree_column, GtkCellRenderer * cell, GtkTreeModel * tree_model, GtkTreeIter * iter, gpointer data);
 void callback_treeview_change(GtkTreeSelection * selection, gpointer data);
 gboolean treeview_canselect(GtkTreeSelection * selection, GtkTreeModel * model, GtkTreePath * path, gboolean path_currently_selected, gpointer userdata);
@@ -100,6 +99,9 @@ void callback_file_open(GtkAction * action, gpointer data);
 gboolean open_file(gchar * filename, MainView * mainview);
 void callback_file_save(GtkAction * action, gpointer data);
 
+void
+checklist_remove_rowrefs(MainView* mainview, GList* rowrefs, gboolean show_results);
+
 /*
  * font/color 
  */
@@ -112,11 +114,14 @@ void callback_sketchlines(GtkAction * action, GtkWidget * wid);
 void callback_color(GtkAction* action, MainView* mainview);
 void callback_color_invoke(GtkAction * action, gpointer data);
 void callback_pressure(GtkAction * action, MainView *mainview);
-void callback_wordwrap(GtkAction * action, MainView *mainview);
+void callback_wordwrap(GtkWidget* widget, gpointer user_data);
 void callback_font(GtkAction * action, gpointer data);
 void callback_fontstyle(GtkAction * action, GtkWidget * wid);
 void callback_textbuffer_move(WPTextBuffer *textbuffer, MainView *mainview);
 
+void callback_sharing(GtkWidget* widget, gpointer user_data);
+void callback_remove_checked(GtkWidget* widget, gpointer user_data);
+
 gint wp_savecallback(const gchar *buffer, GString * gstr);
 
 void callback_undo(GtkAction * action, MainView * mainview);
@@ -127,6 +132,9 @@ void callback_redotoggle(gpointer widget, gboolean st, MainView * mainview);
 
 gboolean close_cb(GtkWidget * widget, GdkEventAny * event, MainView * mainview);
 gboolean on_main_view_key_press(GtkWidget* widget, GdkEventKey* event, gpointer user_data);
+gboolean on_node_view_key_press(GtkWidget* widget, GdkEventKey* event, gpointer user_data);
+gboolean on_main_view_key_release(GtkWidget* widget, GdkEventKey* event, gpointer user_data);
+gboolean on_node_view_key_release(GtkWidget* widget, GdkEventKey* event, gpointer user_data);
 
 gboolean on_checklist_longpress_timeout(gpointer user_data);
 gboolean on_checklist_button_press(GtkWidget* widget, GdkEventButton* event, gpointer user_data);
@@ -150,6 +158,16 @@ void callback_sketch_button_toggled(HildonCheckButton* button, gpointer user_dat
 void callback_buffer_modified(GtkAction * action, gpointer data);
 
 
+const gchar *
+format_overview_name(nodeData *nd, const gchar *name);
+
+gchar *
+he_get_logical_font_desc(const gchar *name);
+
+gchar *
+he_get_logical_font_color(const gchar *name);
+
+
 /* UI helper functions needed in callbacks */
 gboolean
 show_confirmation(MainView* mainview, gchar* question);
@@ -157,12 +175,48 @@ show_confirmation(MainView* mainview, gchar* question);
 void
 show_banner(MainView* mainview, const gchar* text);
 
-gchar*
-show_line_edit_dialog(MainView* mainview,
-                      const gchar* title,
-                      const gchar* label_text,
-                      const gchar* action,
-                      const gchar* text);
+typedef enum {
+    LINE_EDIT_MODE_DEFAULT,
+    LINE_EDIT_MODE_APPEND,
+    LINE_EDIT_MODE_PREPEND,
+} LineEditMode;
 
+#define show_line_edit_dialog(mainview, title, label_text, action, text) \
+   show_line_edit_dialog_full(mainview, title, label_text, action, text, \
+           LINE_EDIT_MODE_DEFAULT)
+
+gchar*
+show_line_edit_dialog_full(MainView* mainview,
+                           const gchar* title,
+                           const gchar* label_text,
+                           const gchar* action,
+                           const gchar* text,
+                           LineEditMode mode);
+
+/* TreeView helper functions */
+
+typedef enum {
+    TREEVIEW_MAINVIEW,
+    TREEVIEW_CHECKLIST,
+} TreeViewType;
+
+void
+treeview_scroll_to_selection(MainView* mainview, TreeViewType type);
+
+typedef enum {
+    TREEVIEW_SELECT_FIRST,
+    TREEVIEW_SELECT_LAST,
+    TREEVIEW_SELECT_PREVIOUS,
+    TREEVIEW_SELECT_NEXT,
+} TreeviewSelectType;
+
+void
+checklist_select(MainView* mainview, TreeviewSelectType type);
+
+void
+nodelist_select(MainView* mainview, TreeviewSelectType type);
+
+void
+checklist_edit_selected(MainView* mainview, LineEditMode mode);
 
 #endif
